Treats a block as if it were received before others with the same work. A can override the effect of an earlier one. The effects of preciousblock are not retained across restarts.
preciousblock(con, blockhash)object of class CONRPC.
character, the hash of the block to mark as precious.
A S4-object of class ANSRPC.
https://bitcoin.org/en/developer-reference#preciousblock, https://bitcoin.org/en/developer-reference#remote-procedure-calls-rpcs
Other Blockchain RPCs: decodescript,
getbestblockhash,
getblockchaininfo,
getblockcount, getblockhash,
getblockheader, getblock,
getchaintips,
getchaintxstats,
getdifficulty,
getmempoolancestors,
getmempooldescendants,
getmempoolentry,
getmempoolinfo,
getrawmempool, gettxoutproof,
gettxoutsetinfo, gettxout,
pruneblockchain, verifychain,
verifytxoutproof