Pruning of blockchain.
pruneblockchain(con, height)A S4-object of class ANSRPC.
object of class CONRPC.
integer The block height to prune up to.
Bernhard Pfaff
May be set to a discrete height, or a unix timestamp to prune blocks whose block time is at least 2 hours older than the provided timestamp.
https://bitcoin.org/en/developer-reference#pruneblockchain, https://bitcoin.org/en/developer-reference#remote-procedure-calls-rpcs
Other Blockchain RPCs: decodescript,
getbestblockhash,
getblockchaininfo,
getblockcount, getblockhash,
getblockheader, getblock,
getchaintips,
getchaintxstats,
getdifficulty,
getmempoolancestors,
getmempooldescendants,
getmempoolentry,
getmempoolinfo,
getrawmempool, gettxoutproof,
gettxoutsetinfo, gettxout,
preciousblock, verifychain,
verifytxoutproof